@@ -41,32 +41,33 @@ class LoadDataKline:
         except Exception as e:
             return self._load(symbol, fetch_since, timeframe, limit=limit, try_times=try_times - 1, *args, **kwargs)
 
-    def load(self, symbol, timeframe='1m', limit=100, unix_start=None, unix_end=None, *args, **kwargs):
+    def load(self, symbol, unix_start, unix_end, timeframe='1m', limit=100, *args, **kwargs):
         unix_max, unix_min = self.table.select_symbol_maxmin(symbol)
         unix_delta = limit * self.exchange.parse_timeframe(timeframe) * 1000
 
-        unix_start = unix_start or self.exchange.milliseconds() - unix_month
-        unix_end = unix_end or self.exchange.milliseconds()
+        unix_start = unix_start
+        unix_end = unix_end
         unix_max = unix_max or self.exchange.milliseconds()
         unix_min = unix_min or self.exchange.milliseconds()
+        print(unix_start, unix_end, unix_max, unix_max)
 
-        unix_temp = unix_min
-        pbar = tqdm(range(unix_min, unix_start, -unix_delta), desc=symbol)
-        for _ in pbar:
-            status, result = self._load(symbol, unix_temp - unix_delta, timeframe=timeframe, limit=limit)
-            if status is False:
-                logger.info("result is null")
-                break
-            pbar.set_postfix({'fetch_since': self.exchange.iso8601(result[0][0])})
-            unix_temp = result[0][0]
+        if unix_min >= unix_start:
+            unix_temp = unix_min
+            pbar = tqdm(range(unix_min, unix_start, -unix_delta), desc=symbol)
+            for _ in pbar:
+                status, result = self._load(symbol, unix_temp - unix_delta, timeframe=timeframe, limit=limit)
+                if status is False:
+                    logger.info("result is null")
+                    break
+                pbar.set_postfix({'fetch_since': self.exchange.iso8601(result[0][0])})
+                unix_temp = result[0][0]
 
         if unix_max >= unix_end:
-            return
-        unix_temp = unix_max
-        pbar = tqdm(range(unix_max, unix_end, unix_delta), desc=symbol)
-        for _ in pbar:
-            status, result = self._load(symbol, unix_temp, timeframe=timeframe, limit=limit)
-            if status is False:
-                print(result)
-                break
-            unix_temp = result[-1][0]
+            unix_temp = unix_max
+            pbar = tqdm(range(unix_max, unix_end, unix_delta), desc=symbol)
+            for _ in pbar:
+                status, result = self._load(symbol, unix_temp, timeframe=timeframe, limit=limit)
+                if status is False:
+                    print(result)
+                    break
+                unix_temp = result[-1][0]
